################
 temBoard Agent
################

This project contains the service monitoring and managing one PostgreSQL
instance.

Please refer to `temBoard <https://labs.dalibo.com/temboard>`_ main project to
know the full picture.
